Exception: ToopherApiError
- Inherits:
-
StandardError
- Object
- StandardError
- ToopherApiError
- Defined in:
- lib/toopher_api.rb
Overview
An exception class used to indicate an error returned by a Toopher API request
An exception class used to indicate an error returned by a Toopher API request